@@ -74,7 +74,7 @@ private:
 
 private:
     struct Private;
-    Private *d;
+    Private *const d;
 };
 
 #endif // BLUEDEVILDAEMON_H
