@@ -21,7 +21,7 @@ class RequestConfirmation : public QObject
 public:
     enum Result {
         Deny,
-        Accept
+        Accept,
     };
 
     explicit RequestConfirmation(BluezQt::DevicePtr device, const QString &pin, QObject *parent = nullptr);
@@ -35,7 +35,7 @@ private Q_SLOTS:
 
 private:
     BluezQt::DevicePtr m_device;
-    QString m_pin;
+    const QString m_pin;
 };
 
 #endif // REQUESTCONFIRMATION_H
